@@ -28,8 +28,11 @@ public:
   void setFont(const QFont&);
   QString currentText() const;
   QString text(int index) const;
-  int  topItem() const;
+  int  currentItem() const;
+  int  visibleTopItem() const;
+  int  visibleBottomItem() const;
   uint count() const;
+  void scrollToItemAtTop(int index);
 
   bool isListVisible() const;
   bool isPredictionsVisible() const;
