@@ -18,7 +18,6 @@
 #include <pwd.h>
 #include <grp.h>
 
-static QStringList CANNA_AF_UNIX_FILES;
 
 CannaEngine::CannaEngine() 
   : _sock(new QTcpSocket(this)), _contxt(0), _convertflag(false), _connectimer(0)
@@ -506,7 +505,7 @@ CannaEngine::recvBeginConvertReply()
 
 
 void
-CannaEngine::endConvert(const QStringList &)
+CannaEngine::endConvert(const QStringList& kanji)
 {
   DEBUG_TRACEFUNC();
   if ( _sock->state() != QAbstractSocket::ConnectedState )
@@ -521,8 +520,15 @@ CannaEngine::endConvert(const QStringList &)
   QDataStream ds(&pack, QIODevice::WriteOnly);
   ds.setByteOrder(QDataStream::BigEndian);
 
-  ds << (quint8)RID_END_CONVERT << (quint8)0 << (quint16)8 << _contxt 
-     << (qint16)0 << (int)0;
+  // ؽǽɲ
+  ds << (quint8)RID_END_CONVERT << (quint8)0 << (quint16)(8 + kanji.count() * 2) << _contxt
+     << (qint16)kanji.count() << (int)1;
+  
+  for (int i = 0; i < (int)kanji.count(); ++i) {
+    QStringList cand;
+    int n = getCandidate(i, cand) ? cand.indexOf(kanji[i]) : 0;
+    ds << (qint16)qMax(n, 0);
+  }
   _sock->write(pack.data(), pack.size());
 
   _convertflag = false;  // conversion done
