@@ -3,14 +3,13 @@
 
 #ifndef KIMERA_NO_DEBUG
 
-#include <qapplication.h>
+#include <qglobal.h>
 
 #define DEBUG_TRACEFUNC(fmt, ...)     TraceFunc ___tracefunc(__func__); \
                                       qDebug("%s-> Enter [%s()] " fmt, TraceFunc::prefix(), __func__, ## __VA_ARGS__)
 
 #define CHECK_NOCHANGE(val, type)     CheckChange<type>  ___Check ## val ## type (val, __FILE__, __LINE__)
 
-
 class TraceFunc {
 public:
   TraceFunc(const char* funcname) : _funcname(funcname) {  ++_callcount; }
@@ -40,8 +39,9 @@ private:
 
 #else
 
-#define DEBUG_TRACEFUNC(fmt, ...) 
-#define CHECK_NOCHANGE(val, type)  
+#define DEBUG_TRACEFUNC(fmt, ...)
+#define CHECK_NOCHANGE(val, type)
+#define qDebug(fmt, ...)
 
 #endif  // KIMERA_NO_DEBUG
 #endif  // DEBUG_H
