@@ -1,9 +1,11 @@
+#include <qpoint.h>
 #include <string.h>
 #include <X11/Xlib.h>
 #include <X11/Xproto.h>
 #include <X11/Xmd.h>
 
-void xEvent2XEvent(Display* dis, const void* src, unsigned int serial, XEvent& e)
+void
+xEvent2XEvent(Display* dis, const void* src, unsigned int serial, XEvent& e)
 {
   xEvent event;
   memcpy(&event, src, sz_xEvent);
