@@ -354,7 +354,11 @@ bool
 KanjiConvert::nextCandidateGroup()
 {
   DEBUG_TRACEFUNC();
-  return  moveCrntItemCandidateList( CandidateListBox::MAX_VISIBLE_ITEMS );
+  int top = _candlist->visibleBottomItem() + 1;
+  int inc = top - _candlist->currentItem();
+  bool res = moveCrntItemCandidateList( inc );
+  _candlist->scrollToItemAtTop( top );
+  return res;
 }
 
 
@@ -370,7 +374,8 @@ bool
 KanjiConvert::previousCandidateGroup()
 {
   DEBUG_TRACEFUNC();
-  return  moveCrntItemCandidateList( -CandidateListBox::MAX_VISIBLE_ITEMS );
+  int dec = _candlist->visibleTopItem() - _candlist->currentItem() - CandidateListBox::MAX_VISIBLE_ITEMS;
+  return moveCrntItemCandidateList( dec );
 }
 
 
@@ -834,7 +839,7 @@ KanjiConvert::decideCandidateList(int no)
     return false;
 
   // Replace string
-  QString str = _candlist->text(_candlist->topItem() + no - 1);
+  QString str = _candlist->text(_candlist->visibleTopItem() + no - 1);
   if (!str.isEmpty()) {
     replaceSegments(_crntsegidx, 1,  QStringList(str));
   }
