@@ -1,14 +1,13 @@
 #include "kimeraapp.h"
 #include "inputmethod.h"
 #include "config.h"
-#include <qregexp.h>
+#include "debug.h"
 
 static InputMethod* inpmethod = 0;
 
 KimeraApp::KimeraApp(int &argc, char **argv) : QApplication(argc, argv)
 {
   qAddPostRoutine( cleanup_ptr );   // delete object
-
   InputMethod::registerXIMServerKimera();  // Register Kimera to X
 }
 
@@ -18,6 +17,7 @@ KimeraApp::KimeraApp(int &argc, char **argv) : QApplication(argc, argv)
 InputMethod* 
 KimeraApp::inputmethod()
 {
+  DEBUG_TRACEFUNC();
   if ( !inpmethod ) {
     inpmethod = new InputMethod();
     Q_CHECK_PTR( inpmethod );
@@ -30,6 +30,7 @@ KimeraApp::inputmethod()
 void
 KimeraApp::cleanup_ptr()
 {
+  DEBUG_TRACEFUNC();
   if (inpmethod)
     delete inpmethod;
   inpmethod = 0;
@@ -40,19 +41,19 @@ bool
 KimeraApp::x11EventFilter(XEvent* event)
 {
   if ( !inpmethod )
-    return FALSE;
+    return false;
 
   if (event->type == ClientMessage) {
-    ClientMessageEvent e(event);
-    sendEvent(inpmethod, &e);
-    return FALSE;
+    XimEvent e((QEvent::Type)KimeraApp::XIMClientMessage, event, sizeof(XEvent));
+    QApplication::sendEvent(inpmethod, &e);
+    return false;
   } else if (event->type >= SelectionClear && event->type <= SelectionNotify) {
-    SelectionEvent e(event);
-    sendEvent(inpmethod, &e);
-    return TRUE;
-  } 
+    XimEvent e((QEvent::Type)KimeraApp::Selection, event, sizeof(XEvent));
+    QApplication::sendEvent(inpmethod, &e);
+    return true;
+  }
   
-  return FALSE;
+  return false;
 }
 
 
