@@ -13,6 +13,7 @@
 #include <QMessageBox>
 #include <QDesktopWidget>
 #include <QHeaderView>
+#include <sys/utsname.h>
 using namespace Kimera;
 
 const int NUM_ROWS = 4;
@@ -124,12 +125,20 @@ PropertyDialog::PropertyDialog(QWidget* parent) : QDialog(parent)
   _ui._grpcmd->setToolTip( tip );
   _ui._cmbcmd->setToolTip( tip );
 
+  // Gets system information
+  QString sysname;
+  struct utsname uts;
+  if (uname(&uts) == 0) {
+    sysname = QString("<p align=\"center\">Qt %1 / %2 %3</p>").arg(qVersion()).arg(uts.sysname).arg(uts.release);
+  }
+
   _ui._lblaboutkimera->setText(tr("<p align=\"center\"><font size=\"+3\"><i>Kimera</i></font><br>"
                                   "Version " KIMERA_VERSION "</p>"
+                                  "%1"
                                   "<p align=\"center\">Copyright (c) 2003-2008  AOYAMA Kazz<br>"
-                                  "http://kimera.sourceforge.jp/</p>"
+                                  "<a href=\"http://kimera.sourceforge.jp/\">http://kimera.sourceforge.jp/</a></p>"
                                   "<p align=\"center\">This program is distributed under the terms of "
-                                  "the GNU GENERAL PUBLIC LICENSE Version 3.</p>"));
+                                  "the GNU GENERAL PUBLIC LICENSE Version 3.</p>").arg(sysname));
   
   // Sets Kanji engine name
   QStringList englst = KanjiEngine::kanjiEngineList();
