@@ -1,8 +1,7 @@
 #ifndef SUPPORTATTR_H
 #define SUPPORTATTR_H
 
-#include <qcstring.h>
-#include <sys/types.h>
+#include <QByteArray>
 
 enum ValueType {
   TYPE_SEPARATOR = 0,
@@ -26,16 +25,16 @@ enum ValueType {
 // IM and IC attributes supported class  
 class SupportAttr {
 public:
-  SupportAttr(u_int16_t i, QCString str, ValueType t) : _id(i), _attr(str), _type(t) { }
+  SupportAttr(quint16 i, QByteArray str, ValueType t) : _id(i), _attr(str), _type(t) { }
   SupportAttr() { }
 
-  u_int16_t  id() const { return _id; }
-  QCString   attribute() const { return _attr; }
+  quint16    id() const { return _id; }
+  QByteArray attribute() const { return _attr; }
   ValueType  type() const { return _type; }
 
 private:
-  u_int16_t    _id;
-  QCString     _attr;
+  quint16      _id;
+  QByteArray   _attr;
   ValueType    _type;
 };
 
