@@ -1,13 +1,12 @@
 #include "tomoeengine.h"
 #include "debug.h"
-#include <qprocess.h>
-#include <qdir.h>
+#include <QProcess>
+#include <QDir>
 
 TomoeEngine::TomoeEngine()
-  : _tomoe(0)
+  : _tomoe(new QProcess(this))
 {
-  _tomoe = new QProcess(QString("kimera-tomoe-gtk"), this);
-  connect(_tomoe, SIGNAL(readyReadStdout()), this, SLOT(readFromStdout()));
+  connect(_tomoe, SIGNAL(readyReadStandardOutput()), this, SLOT(readFromStdout()));
 }
 
 
@@ -27,11 +26,12 @@ TomoeEngine::init()
 {
   DEBUG_TRACEFUNC();
 
-  if (_tomoe->isRunning())
-    return TRUE;
+  if (_tomoe->state() != QProcess::NotRunning)
+    return true;
 
-  _tomoe->setWorkingDirectory(QDir::homeDirPath());
-  return _tomoe->start();
+  _tomoe->setWorkingDirectory(QDir::homePath());
+  _tomoe->start("kimera-tomoe-gtk");
+  return true;
 }
 
 
@@ -46,7 +46,7 @@ TomoeEngine::cleanup()
 bool
 TomoeEngine::beginConvert(const QString&, QStringList&, QStringList&)
 {
-  return TRUE;
+  return true;
 }
 
 
@@ -58,14 +58,14 @@ TomoeEngine::endConvert(const QStringList&)
 bool
 TomoeEngine::getCandidate(int, QStringList&)
 {
-  return TRUE;
+  return true;
 }
 
 
 bool
 TomoeEngine::resizeSegment(int, int, QStringList&, QStringList&)
 {
-  return TRUE;
+  return true;
 }
 
 
@@ -75,23 +75,14 @@ TomoeEngine::readFromStdout()
   DEBUG_TRACEFUNC();
   const QString prefix("commit_string:\t");
 
-  while (_tomoe->canReadLineStdout()) {
-    QByteArray str = _tomoe->readStdout();
+  while (_tomoe->canReadLine()) {
+    QByteArray str = _tomoe->readAll();
     QString line = QString::fromUtf8(str.data(), str.size()).section('\n', -2, -2);
-    if ( line.startsWith(prefix, FALSE) ) {
-      qDebug("String commited(%d): %s", line.length(), line.mid(prefix.length()).local8Bit().data() );
+    if ( line.startsWith(prefix, Qt::CaseInsensitive) ) {
+      qDebug("String commited(%d): %s", line.length(), qPrintable(line.mid(prefix.length())));
       emit decided(line.mid(prefix.length()));
     }
   }
-  
-
-//   while (_tomoe->canReadLineStdout()) {
-//     QString str = _tomoe->readLineStdout();
-//     if ( str.startsWith(prefix, FALSE) ) {
-//       qDebug("String commited: %s", str.mid(prefix.length()).local8Bit().data() );
-//       emit decided(  str.mid(prefix.length()));
-//     };
-//   }
 }
 
 
